Function encoding_c::encoding_new_encoder_into
[−]
[src]
#[no_mangle]pub unsafe extern fn encoding_new_encoder_into(encoding: *const Encoding,
encoder: *mut Encoder)
Allocates a new Encoder for the given Encoding into memory provided by
the caller. (In practice, the target should likely be a pointer previously
returned by encoding_new_encoder().)
Undefined behavior
UB ensues if either argument is NULL.